---
name: 🎁 Feature Request
about: Make a feature suggestion
title: "[FEATURE]"
labels: enhancement
assignees: ''
---

### Is your feature request related to a problem

Is your feature request related to a problem?

Add a clear and concise description of what the problem is.

For example; I want to be able to [...] but I can't because [...]

### The solution you would like

Add a clear and concise description of what you want to happen.

### Describe alternatives you have considered

Add a clear and concise description of any alternative solutions or features you have considered.

### Additional context

Add any other context, screenshots, links, et cetera about the feature request here.
